
Multi node Devstack deployment using Ansible
============================================

Ansible is a configuration management utility.  It runs on a system separate from Devstack nodes to handle execution of devstack scripts and system reboots.

Instructions in this readme have been tested with Ansible version 1.9.4.

1. Install Ansible 1.9.4 on a system (VM or physical) separate from ones to be used for Devstack deployment.


2. Have two systems with fresh installations of chosen OS standing by.


3. On the Ansible system, create a file in the Ansible directory called ``inventory.ini``.  This file holds information regarding which system is control and which is compute.
   Group vars are used to specify login credentials.  Alternatively, a pre-shared ssh key can be used.  See examples below.


        [control]
        # Only use 'ansible_ssh_host' here to set IP if DNS is not configured
        # The hostname must match the hostname in the ``node_info`` section in onps_config.yml (details in subsequent section of this readme)
        # This hostname will be set on the node
        control-1.example.com  ansible_ssh_host=1.2.3.a

        [compute]
        compute-1.example.com  ansible_ssh_host=1.2.3.c
        # Optionally, per node passwords are supported
        compute-2.example.com  ansible_ssh_host=1.2.3.d ansible_ssh_pass=something_different

        [control:vars]
        ansible_ssh_user=root
        ansible_ssh_pass=mypass

        [compute:vars]
        ansible_ssh_user=root
        ansible_ssh_pass=mypass

        # Or, use the global group 'all' (or -k to provide a password on the command line)
        [all:vars]
        ansible_ssh_user=root
        ansible_ssh_pass=mypass

   Only one method of supplying login credentials should be chosen.
   See also http://docs.ansible.com/ansible/intro_inventory.html


4. Use Ansible to probe systems and gather facts about network topology for Devstack systems.

        ansible -i inventory.ini -m setup control:compute  > all_system_facts.txt

   Examine all_system_facts.txt to get all current network topology details.
   e.g.


        "ansible_interfaces": [
            "ens785f0",
            "lo",
            "ens785f2",
            "ens785f3",
            "ens513f1",
            "ens513f0",
            "mgmt",
            "virtual-1",
            "inter",
            "virbr0-nic",
            "virbr0"
        ],
        "ansible_ens513f1": {
            "active": false,
            "device": "ens513f1",
            "macaddress": "00:1e:67:e2:6f:25",
            "module": "ixgbe",
            "mtu": 1500,
            "promisc": false,
            "type": "ether"
        },
        "ansible_ens785f0": {
            "active": false,
            "device": "ens785f0",
            "macaddress": "68:05:ca:37:dc:68",
            "module": "i40e",
            "mtu": 1500,
            "promisc": false,
            "type": "ether"
        },


5. Edit onps_config.yml.
    - Define ovs_type, tenant_network_type and use_odl.  Other configuration options can be left at default values.
      Info regarding available options are outlined as comments in onps_config.yml.
    - Using info in all_system_facts.txt, set interface names for mgmt (management), inter (internet), public and tenant networks.
    - Define static IPs for interfaces that need them (tunnel_ip and mgmt ip_address typically) in ``node_info`` section.
      Since we stack all nodes in parallel, every node has to know the full topology and IP address of every other node.
    - Optionally, speed up devstack by using a local pip cache mirror.

        pip_mirror_url: http://local-pip-mirror.example.com:4040/root/pypi/+simple/


6. Set ANSIBLE_LOG_BASE enviroment variable to a desired log path and run the multinode.yml playbook.

         ANSIBLE_LOG_BASE=/tmp/logs/$(date +%Y%m%d%H%M%S) ANSIBLE_LOG_PATH=$(ANSIBLE_LOG_BASE)/multinode.log ansible-playbook -i inventory.ini multinode.yml


7. Logs from the playbook run will be copied from system to the log path specified (ANSIBLE_LOG_BASE).


8. SSH to the control node.

   Using Nova, verify that the control node can communicate with the compute node.

        nova hypervisor-show 1

   If this command fails, then the control and compute nodes are not communicating.

   To diagnose possible causes, run the ``rejoin-stack.sh`` script in /home/stack/devstack/ on the control node to reattach to the Devstack Screen session.
   Cycle through each screen, looking for errors.  Errors will appear as red text.
   Some useful Screen shortcuts:
    - Ctrl+a n : next window
    - Ctrl+a p : previous window
    - Ctrl+a " : select specific window from a list of available windows
    - Ctrl+a ' : select specific window by entering the window name
    - Ctrl+a d : detach from Screen session


9. If no errors occurred and the command in step 8 is successful, Devstack has been successfullly deployed.


How to add compute nodes after stacking
=======================================

1. Add the new node(s) and its login credentials to the inventory.ini file.

        [control]
        existing-control-1.example.com ansible_ssh_host=1.2.3.4


        [compute]
        existing-compute-1.example.com   ansible_ssh_host=1.2.3.5
        new-compute-1.example.com   ansible_ssh_host=1.2.3.6
        ...
        new-compute-n.example.com   ansible_ssh_host=1.2.3.n


2. Edit onps_config.yml and add the new node(s) to node_info.


    node_info:
        existing-control-1.example.com:
           networks:
              mgmt:
                 ip_address: 1.2.3.4
        ...
        existing-compute-1.example.com:
           networks:
              mgmt:
                 ip_address: 1.2.3.5_
        ...
        new-compute-1.example.com:
           networks:
              mgmt:
                 ip_address: 1.2.3.6
        ...
        new-compute-n.example.com:
           networks:
             mgmt:
                 ip_address: 1.2.3.n


3. Use the --limit argument on another Ansible playbook run to add the new node(s) to the stack.

        ansible-playbook -i inventory.ini  multinode.yml  --limit=new-compute-1.example.com

   This will tell Ansible to run only on the new node.   The new compute node will use the info from ``node_info`` and nodes in the control group to find the IP address of the controller, in this example  ``1.2.3.4``

   Repeat the Ansible playbook run for each new node to be added.
