#!/usr/bin/env python
#
# Copyright (c) 2015, Intel Corporation
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#    * Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#    * Neither the name of Intel Corporation nor the names of its contributors
#      may be used to endorse or promote products derived from this software
#      without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

from __future__ import print_function
import argparse
import os

import pytest


def read_file(pth):
    with open(pth) as file_obj:
        return file_obj.readlines()

# ignore_comments = True

def split_line(l):
    if '=' in l:
        return [s.strip() for s in l.split('=')]
    elif l.startswith("#"):
        return l.strip(), ""
    else:
        splits = [s.strip() for s in l.split()]
        return " ".join(splits[0:2]), " ".join(splits[2:])


def parse_file(lines):
    if os.environ.get('ignore_comments'):
        line_iter = (l for l in lines if not l.startswith('#'))
    else:
        line_iter = lines
    return dict(split_line(l) for l in line_iter)


# def parse_file(lines):
#     splits = (l.split("=") for l in lines)
#     return {s[0].strip(): s[1].strip() if len(s) == 2 else '' for s in splits}


def test_local_conf():
    conf1 = parse_file(read_file(os.environ['local_conf_1']))
    conf2 = parse_file(read_file(os.environ['local_conf_2']))
    assert conf1 == conf2

if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument(u"--include-comments", action="store_false", dest="ignore_comments",
                        help=u"onp configuration files, default=%(default)s")
    parser.add_argument(u"file_1", help=u"first local.conf")
    parser.add_argument(u"file_2", help=u"second local conf")

    args = parser.parse_args()
    if args.ignore_comments:
        os.environ['ignore_comments'] = "1"
    os.environ['local_conf_1'] = args.file_1
    os.environ['local_conf_2'] = args.file_2

    print(args.file_1)
    pytest.main("-vv {}".format(__file__))
